// Minimalistic UI plugin bootstrap.
var pluginApi = parent.pluginApi('sdk-testdrive');
pluginApi.register({
    RestApiSessionAcquired: function () {
        testDrive();
    }
});
pluginApi.ready();

// Take oVirt.js prototype for a ride.
function testDrive () {
    function randomInteger (min, max) {
        return Math.floor(Math.random() * (max - min + 1) + min);
    }

    // Obtain DataCenter resource collection.
    var dcColl = ovirt.api.datacenters;

    // Add new DataCenter, passing data as expected by RESTful backend.
    dcColl.add({
        name: 'test-dc-' + randomInteger(0, 1000),
        local: false
    }).success(dcAddedCallback).run();

    function dcAddedCallback (dc) {
        console.log('Added: ' + dc.data().name);
        // Modify DataCenter's description.
        dc.data().description = 'Updated at ' + new Date().toISOString();
        // Update DataCenter, callback gets the same 'dc' object.
        dc.update().success(dcUpdatedCallback).run();
    }

    function dcUpdatedCallback (dc) {
        console.log('Updated: ' + dc.data().name);
        // Delete DataCenter, callback gets HTTP DELETE response as object.
        dc.delete().success(dcDeletedCallback).run();
    }

    function dcDeletedCallback (deleteResponse) {
        console.log('Deleted: ' + deleteResponse.status.state);
    }

    // List all DataCenters.
    dcColl.list().success(dcsListedCallback).run();

    function dcsListedCallback (dcArray) {
        dcArray.forEach(function (dc) {
            console.log('Listed: ' + dc.data().name);
            // Get DataCenter by ID.
            dcColl.get(dc.data().id).success(dcGotByIdCallback).run();
        });
    }

    function dcGotByIdCallback (dc) {
        console.log('Got by ID: ' + dc.data().name);
    }
}
